package com.yijia.station.controller;

import java.math.BigDecimal;
import java.text.DateFormat;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.time.format.DateTimeFormatter;
import java.util.*;

import com.yijia.station.domain.PayOrder;
import com.yijia.station.domain.StationClassesSummary;
import com.yijia.station.domain.StationDeviceManage;
import com.yijia.station.mapper.PayOrderMapper;
import com.yijia.station.service.IPayOrderService;
import com.yijia.station.service.IStationClassesSummaryService;
import com.yijia.station.service.IStationDeviceManageService;
import com.yijia.station.utils.FeiEPrinterUtil;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.yijia.common.annotation.Log;
import com.yijia.common.core.controller.BaseController;
import com.yijia.common.core.domain.AjaxResult;
import com.yijia.common.enums.BusinessType;
import com.yijia.station.domain.StationClassStructure;
import com.yijia.station.service.IStationClassStructureService;
import com.yijia.common.utils.poi.ExcelUtil;
import com.yijia.common.core.page.TableDataInfo;

/**
 * 班结管理Controller
 * 
 * @author yijia
 * @date 2020-12-31
 */
@RestController
@RequestMapping("/station/structure")
public class StationClassStructureController extends BaseController
{
    @Autowired
    private IStationClassStructureService stationClassStructureService;
    @Autowired
    private IPayOrderService payOrderService;
    @Autowired
    private IStationClassesSummaryService stationClassesSummaryService;
    @Autowired
    private IStationDeviceManageService stationDeviceManageService;

    /**
     * 查询班结管理列表
     */
    @PreAuthorize("@ss.hasPermi('station:structure:list')")
    @GetMapping("/list")
    public TableDataInfo list(StationClassStructure stationClassStructure)
    {
        startPage();
        List<StationClassStructure> list = stationClassStructureService.selectStationClassStructureList(stationClassStructure);
        return getDataTable(list);
    }

    @PreAuthorize("@ss.hasPermi('station:structure:listPersonnelStructure')")
    @GetMapping("/listPersonnelStructure")
    public TableDataInfo listPersonnelStructure(StationClassStructure stationClassStructure)
    {
        List<StationClassStructure> list = new ArrayList<>();
        if(stationClassStructure!=null &&stationClassStructure.getStationId()!=null ){
          list = stationClassStructureService.listPersonnelStructure(stationClassStructure);
        }
        return getTable(list);
    }

    @PreAuthorize("@ss.hasPermi('station:structure:listOilStructure')")
    @GetMapping("/listOilStructure")
    public TableDataInfo listOilStructure(StationClassStructure stationClassStructure)
    {
        List<StationClassStructure> list = new ArrayList<>();
        if(stationClassStructure!=null &&stationClassStructure.getStationId()!=null ){
            list = stationClassStructureService.listOilStructure(stationClassStructure);
        }
        return getTable(list);
    }
    @PreAuthorize("@ss.hasPermi('station:structure:listPersonnelPayStructure')")
    @GetMapping("/listPersonnelPayStructure")
    public TableDataInfo listPersonnelPayStructure(StationClassStructure stationClassStructure)
    {
        List<StationClassStructure> list = new ArrayList<>();
        if(stationClassStructure!=null &&stationClassStructure.getStationId()!=null ){
            list = stationClassStructureService.listPersonnelPayStructure(stationClassStructure);
        }
        return getTable(list);
    }
    @PreAuthorize("@ss.hasPermi('station:structure:listClass')")
    @GetMapping("/listClass")
    public AjaxResult listClass(StationClassStructure stationClassStructure)
    {

        return AjaxResult.success(stationClassStructureService.listClass(stationClassStructure));
    }
    /**
     * 导出班结管理列表
     */
    @PreAuthorize("@ss.hasPermi('station:structure:export')")
    @Log(title = "班结管理", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(StationClassStructure stationClassStructure)
    {
        List<StationClassStructure> list = stationClassStructureService.selectStationClassStructureExport(stationClassStructure);
        ExcelUtil<StationClassStructure> util = new ExcelUtil<StationClassStructure>(StationClassStructure.class);
        return util.exportExcel(list, "structure");
    }

    /**
     * 获取班结管理详细信息
     */
    @PreAuthorize("@ss.hasPermi('station:structure:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(stationClassStructureService.selectStationClassStructureById(id));
    }


    /**
     * 新增班结管理
     */
    @PreAuthorize("@ss.hasPermi('station:structure:add')")
    @Log(title = "班结管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody StationClassStructure stationClassStructure) throws ParseException {
        //获取当前班结油站
        // Long stationId=stationClassStructure.getStationId();
        Long stationId= Long.valueOf("5");
        String stationName=stationClassStructure.getStationName();
        String username = stationClassStructure.getClassStructureMan();
        //根据油站查询出油站是否班结过，班结过就需要查询上次班结的时间
        StationClassStructure classes =new StationClassStructure();
        classes.setStationId(stationId);
        //查询出上次班结，最后一条数据
        StationClassStructure sss =stationClassStructureService.selectStationClassStructureMax(classes);
        String beginTime="";
        //当前时间
        Date date= new Date();
        StationClassStructure classesStructure =new StationClassStructure();
        classesStructure.setStationId(stationId);
        DateFormat dFormat = new SimpleDateFormat("yyyyMMdd");
        String no=dFormat.format(date);
        classesStructure.setLikeClassStructureNo(no);
        //查询班结信息中本日班结次数
        StationClassStructure structure =stationClassStructureService.selectDistnctClassStructure(classesStructure);
        if(structure!=null){
            if(structure.getNum()==0){
                no = no + "0"+1;
            }else{
                int num  = structure.getNum()+1;
                if(num>0 && num<10){
                    no = no + "0"+num;
                }else{
                    no = no +""+ num;
                }
            }
        }
        int i=0;
        DateFormat dateFormat = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        if(sss!=null){
            //获取上次班结时间
            PayOrder order=new PayOrder();
            order.setStationId(stationId);
            order.setStatus("1");
            beginTime= dateFormat.format(sss.getClassStructureDate());
            order.setBeginTime(beginTime);
            order.setEndTime( dateFormat.format(date));
            SimpleDateFormat dfe = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
            List<PayOrder> list = payOrderService.selectPayOrderList(order);
            for(PayOrder payOrder:list){
                StationClassStructure stationclass =new StationClassStructure();
                stationclass.setStationId(payOrder.getStationId());
                stationclass.setStationName(payOrder.getStationName());
                stationclass.setClassStartDate(dfe.parse(beginTime));
                stationclass.setClassStructureMan(username);
                stationclass.setClassStructureNo(no);
                stationclass.setClassStructureDate(date);
                stationclass.setOrderNo(payOrder.getOrderNo());
                stationclass.setOilGun(payOrder.getOilGun());
                stationclass.setOilName(payOrder.getOilName());
                stationclass.setConsumerId(payOrder.getConsumerId());
                stationclass.setConsumer(payOrder.getConsumer());
                stationclass.setAmt(payOrder.getAmt());
                if(payOrder.getReceivableAmt()!=null){
                    stationclass.setReceivableAmt(payOrder.getReceivableAmt());
                }else{
                    stationclass.setReceivableAmt(BigDecimal.valueOf(0));
                }
                if(payOrder.getReceivedAmt()!=null){
                    stationclass.setReceivedAmt(payOrder.getReceivedAmt());
                }else{
                    stationclass.setReceivedAmt(BigDecimal.valueOf(0));
                }
                if(payOrder.getDiscountAmt()!=null){
                    stationclass.setDiscountAmt(payOrder.getDiscountAmt());
                }else{
                    stationclass.setDiscountAmt(BigDecimal.valueOf(0));
                }
                if(payOrder.getDiscountCouponAmt()!=null){
                    stationclass.setDiscountCouponAmt(payOrder.getDiscountCouponAmt());
                }else{
                    stationclass.setDiscountCouponAmt(BigDecimal.valueOf(0));
                }
                if(payOrder.getWxAmt()!=null){
                    stationclass.setWxAmt(payOrder.getWxAmt());
                }else{
                    stationclass.setWxAmt(BigDecimal.valueOf(0));
                }
                if(payOrder.getZfbAmt()!=null){
                    stationclass.setZfbAmt(payOrder.getZfbAmt());
                }else{
                    stationclass.setZfbAmt(BigDecimal.valueOf(0));
                }
                if(payOrder.getPosAmt()!=null){
                    stationclass.setPosAmt(payOrder.getPosAmt());
                }else{
                    stationclass.setPosAmt(BigDecimal.valueOf(0));
                }
                if(payOrder.getXjAmt()!=null){
                    stationclass.setXjAmt(payOrder.getXjAmt());
                }else{
                    stationclass.setXjAmt(BigDecimal.valueOf(0));
                }
                if(payOrder.getDidiAppAmt()!=null){
                    stationclass.setDidiAppAmt(payOrder.getDidiAppAmt());
                }else{
                    stationclass.setDidiAppAmt(BigDecimal.valueOf(0));
                }
                if(payOrder.getTyAppAmt()!=null){
                    stationclass.setDidiAppAmt(payOrder.getTyAppAmt());
                }else{
                    stationclass.setDidiAppAmt(BigDecimal.valueOf(0));
                }
                if(payOrder.getOtherAmt()!=null){
                    stationclass.setOtherAmt(payOrder.getOtherAmt());
                }else{
                    stationclass.setOtherAmt(BigDecimal.valueOf(0));
                }
                if(payOrder.getDzkAmt()!=null){
                    stationclass.setDzkAmt(payOrder.getDzkAmt());
                }else{
                    stationclass.setDzkAmt(BigDecimal.valueOf(0));
                }
                if(payOrder.getMemberAmt()!=null){
                    stationclass.setMemberAmt(payOrder.getMemberAmt());
                }else{
                    stationclass.setMemberAmt(BigDecimal.valueOf(0));
                }
                stationclass.setOrderLiters(payOrder.getOrderLiters());
                stationclass.setPayWay(payOrder.getPayWay());
                stationclass.setPayType(payOrder.getPayType());
                stationclass.setPayDate(payOrder.getPayDate());
                stationclass.setOilPersonnel(payOrder.getOilPersonnel());
                stationclass.setOrderType(payOrder.getOrderType());
                if(payOrder.getPrintCount()!=null){
                    stationclass.setPrintNum(payOrder.getPrintCount());
                }else{
                    stationclass.setPrintNum(Long.valueOf("0"));
                }

                i= stationClassStructureService.insertStationClassStructure(stationclass);
            }
        }else{
            //初次班结 班结时间默认为当前时间，班结人username
            //根据班结时间查询订单
            PayOrder order=new PayOrder();
            order.setStationId(stationId);
            order.setEndTime(dateFormat.format(date));
            List<PayOrder> list = payOrderService.selectPayOrderList(order);
            for(PayOrder payOrder:list){
                StationClassStructure stationclass =new StationClassStructure();
                stationclass.setStationId(payOrder.getStationId());
                stationclass.setStationName(payOrder.getStationName());
                stationclass.setClassStructureMan(username);
                stationclass.setClassStructureDate(date);
                stationclass.setClassStructureNo(no);
                stationclass.setOrderNo(payOrder.getOrderNo());
                stationclass.setOilGun(payOrder.getOilGun());
                stationclass.setOilName(payOrder.getOilName());
                stationclass.setConsumerId(payOrder.getConsumerId());
                stationclass.setConsumer(payOrder.getConsumer());
                stationclass.setAmt(payOrder.getAmt());
                if(payOrder.getReceivableAmt()!=null){
                    stationclass.setReceivableAmt(payOrder.getReceivableAmt());
                }else{
                    stationclass.setReceivableAmt(BigDecimal.valueOf(0));
                }
                if(payOrder.getReceivedAmt()!=null){
                    stationclass.setReceivedAmt(payOrder.getReceivedAmt());
                }else{
                    stationclass.setReceivedAmt(BigDecimal.valueOf(0));
                }
                if(payOrder.getDiscountAmt()!=null){
                    stationclass.setDiscountAmt(payOrder.getDiscountAmt());
                }else{
                    stationclass.setDiscountAmt(BigDecimal.valueOf(0));
                }
                if(payOrder.getDiscountCouponAmt()!=null){
                    stationclass.setDiscountCouponAmt(payOrder.getDiscountCouponAmt());
                }else{
                    stationclass.setDiscountCouponAmt(BigDecimal.valueOf(0));
                }
                if(payOrder.getWxAmt()!=null){
                    stationclass.setWxAmt(payOrder.getWxAmt());
                }else{
                    stationclass.setWxAmt(BigDecimal.valueOf(0));
                }
                if(payOrder.getZfbAmt()!=null){
                    stationclass.setZfbAmt(payOrder.getZfbAmt());
                }else{
                    stationclass.setZfbAmt(BigDecimal.valueOf(0));
                }
                if(payOrder.getPosAmt()!=null){
                    stationclass.setPosAmt(payOrder.getPosAmt());
                }else{
                    stationclass.setPosAmt(BigDecimal.valueOf(0));
                }
                if(payOrder.getXjAmt()!=null){
                    stationclass.setXjAmt(payOrder.getXjAmt());
                }else{
                    stationclass.setXjAmt(BigDecimal.valueOf(0));
                }
                if(payOrder.getDidiAppAmt()!=null){
                    stationclass.setDidiAppAmt(payOrder.getDidiAppAmt());
                }else{
                    stationclass.setDidiAppAmt(BigDecimal.valueOf(0));
                }
                if(payOrder.getTyAppAmt()!=null){
                    stationclass.setDidiAppAmt(payOrder.getTyAppAmt());
                }else{
                    stationclass.setDidiAppAmt(BigDecimal.valueOf(0));
                }
                if(payOrder.getOtherAmt()!=null){
                    stationclass.setOtherAmt(payOrder.getOtherAmt());
                }else{
                    stationclass.setOtherAmt(BigDecimal.valueOf(0));
                }
                if(payOrder.getDzkAmt()!=null){
                    stationclass.setDzkAmt(payOrder.getDzkAmt());
                }else{
                    stationclass.setDzkAmt(BigDecimal.valueOf(0));
                }
                if(payOrder.getMemberAmt()!=null){
                    stationclass.setMemberAmt(payOrder.getMemberAmt());
                }else{
                    stationclass.setMemberAmt(BigDecimal.valueOf(0));
                }
                stationclass.setOrderLiters(payOrder.getOrderLiters());
                stationclass.setPayWay(payOrder.getPayWay());
                stationclass.setPayType(payOrder.getPayType());
                stationclass.setPayDate(payOrder.getPayDate());
                stationclass.setOilPersonnel(payOrder.getOilPersonnel());
                stationclass.setOrderType(payOrder.getOrderType());
                if(payOrder.getPrintCount()!=null){
                    stationclass.setPrintNum(payOrder.getPrintCount());
                }else{
                    stationclass.setPrintNum(Long.valueOf("0"));
                }
                i= stationClassStructureService.insertStationClassStructure(stationclass);
            }
        }
        StationClassStructure scs =new StationClassStructure();
        scs.setClassStructureNo(no);
        //汇总班结数据将汇总的数据插入到汇总数据中
        StationClassStructure stationclass = stationClassStructureService.selectSummyClassStructure(scs);
        if(stationclass!=null){
            StationClassesSummary stationClassesSummary =new StationClassesSummary();
            stationClassesSummary.setClassesNo(stationclass.getClassStructureNo());
            if(stationclass.getClassStartDate()!=null){
                stationClassesSummary.setStartDate(stationclass.getClassStartDate());
            }
            if(stationclass.getClassStructureDate()!=null){
                stationClassesSummary.setEndDate(stationclass.getClassStructureDate());
            }

            stationClassesSummary.setStationName(stationclass.getStationName());
            if(stationclass.getStationId()!=null){
                stationClassesSummary.setStationId(stationclass.getStationId());
            }
            if(stationclass.getNum()!=null){
                stationClassesSummary.setOrderNum(Long.valueOf(stationclass.getNum()));
            }
            if(stationclass.getPrintNum()!=null){
                stationClassesSummary.setPrintNum(stationclass.getPrintNum());
            }
            if(stationclass.getOrderLiters()!=null){
                stationClassesSummary.setSaleLiters(stationclass.getOrderLiters());
            }
            if(stationclass.getAmt()!=null){
                stationClassesSummary.setSaleAmt(stationclass.getAmt());
            }
            if(stationclass.getDzkAmt()!=null){
                stationClassesSummary.setDzkAmt(stationclass.getDzkAmt());
            }else{
                stationClassesSummary.setDzkAmt(BigDecimal.valueOf(0));
            }
            if(stationclass.getZfbAmt()!=null){
                stationClassesSummary.setZfbAmt(stationclass.getZfbAmt());
            }else{
                stationClassesSummary.setZfbAmt(BigDecimal.valueOf(0));
            }

            if(stationclass.getWxAmt()!=null){
                stationClassesSummary.setWxAmt(stationclass.getWxAmt());
            }else{
                stationClassesSummary.setWxAmt(BigDecimal.valueOf(0));
            }
            stationClassesSummary.setClassesMan(stationclass.getClassStructureMan());
            i=stationClassesSummaryService.insertStationClassesSummary(stationClassesSummary);
        }
        if(i==1){
            //班结成功，打印小票
            //查询班结小票数据
            StationClassStructure classStructure= new StationClassStructure();
            classStructure.setClassStructureNo(no);
            List<StationClassStructure>  list= stationClassStructureService.listOilStructure(classStructure);
            //查询出小票数据
            String content;
            content = "<CB>班结小票</CB><BR>";
            content += "--------------------------------<BR>";
            if(list!=null && list.size()>0){
                if(list.get(0).getClassStartDate()!=null){
                    content += "开始时间："+dateFormat.format(list.get(0).getClassStartDate())+"  <BR>";
                }else{
                    content += "开始时间： <BR>";
                }
                content += "班结时间："+dateFormat.format(list.get(0).getClassStructureDate())+" <BR>";
                content += "油品  升数  金额  单数  优惠  <BR>";
                content += "--------------------------------<BR>";

                BigDecimal sumAmt = new BigDecimal(0);
                BigDecimal liters = new BigDecimal(0);
                BigDecimal coupon = new BigDecimal(0);
                BigDecimal ysAmt =  new BigDecimal(0);
                int num = 0;
                int pageNum=0;
                for(StationClassStructure str : list){
                    if( str.getOrderLiters()==null){
                        str.setOrderLiters(BigDecimal.valueOf(0));
                    }
                    //实收金额
                    if( str.getAmt()==null){
                        str.setAmt(BigDecimal.valueOf(0));
                    }
                    //应付金额
                    if( str.getReceivableAmt()==null){
                        str.setReceivableAmt(BigDecimal.valueOf(0));
                    }
                    if( str.getDiscountAmt()==null){
                        str.setDiscountAmt(BigDecimal.valueOf(0));
                    }
                    if( str.getOrderNo()==null){
                        str.setOrderNo(String.valueOf(0));
                    }
                    content += str.getOilName()+"  "+str.getOrderLiters()+"  "+str.getAmt()+"  "+str.getOrderNo()+"  "+str.getDiscountAmt()+ " <BR>";
                    if(str.getAmt()!=null){
                        sumAmt=sumAmt.add(str.getAmt());
                    }
                    if(str.getReceivableAmt()!=null){
                        ysAmt=ysAmt.add(str.getReceivableAmt());
                    }
                    if(str.getOrderLiters()!=null){
                        liters=liters.add(str.getOrderLiters());
                    }
                    if(str.getOrderNo()!=null){
                        num= num+Integer.parseInt(str.getOrderNo());
                    }
                    if(str.getDiscountAmt()!=null){
                        coupon=coupon.add(str.getDiscountAmt());
                    }
                    if(str.getPrintNum()!=null){
                        pageNum += str.getPrintNum();
                    }
                }
                content += "--------------------------------<BR>";
                content += "合计  "+liters+"  "+sumAmt+"  "+num+"  "+coupon+"<BR>";
                content += "小票张数： "+pageNum+" 张<BR>";
                content += "班结金额： "+ysAmt+" 元<BR>";
                content += "优惠总额： "+coupon+" 元<BR>";
                content += "实际支付： "+sumAmt+" 元<BR>";
                content += "班结人： "+list.get(0).getClassStructureMan()+"<BR>";
            }else{
                content += "开始时间： <BR>";
                content += "班结时间： <BR>";
                content += "油站  升数  金额  单数  优惠  <BR>";
                content += "--------------------------------<BR>";
                content += "合计  <BR>";
                content += "小票张数：<BR>";
                content += "班结金额：<BR>";
                content += "优惠总额：<BR>";
                content += "实际支付： <BR>";
                content += "班结人：<BR>";
            }
            content += "<BR>";
            content += "--------------------------------<BR>";
            content += "<BR>";
            //查询打印机信息
            Map params  =new HashMap();
            params.put("stationId", list.get(0).getStationId());
            params.put("deviceType", "3");
            Map mp  = stationDeviceManageService.getPrinterSnByStationId(params);
            System.out.println(mp);
            if(mp.containsKey("device_no") && mp.get("device_no")!= null && mp.get("device_no")!=""){
               String sn = mp.get("device_no").toString();
               FeiEPrinterUtil.printReceipt(sn, content);
            }else {
                logger.info("请正确配置打印机");
            }
        }
        return toAjax(i);

    }

    /**
     * 修改班结管理
     */
    @PreAuthorize("@ss.hasPermi('station:structure:edit')")
    @Log(title = "班结管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody StationClassStructure stationClassStructure)
    {
        return toAjax(stationClassStructureService.updateStationClassStructure(stationClassStructure));
    }

    /**
     * 删除班结管理
     */
    @PreAuthorize("@ss.hasPermi('station:structure:remove')")
    @Log(title = "班结管理", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(stationClassStructureService.deleteStationClassStructureByIds(ids));
    }

    /**
     * 查询上次班结数据
     */
    @PreAuthorize("@ss.hasPermi('station:structure:getAgeClassStructure')")
    @GetMapping("/getAgeClassStructure")
    public AjaxResult getAgeClassStructure(StationClassStructure stationClassStructure)
    {
        stationClassStructure.setStationId(Long.valueOf("5"));
        return AjaxResult.success(stationClassStructureService.selectStationClassStructureMax(stationClassStructure));
    }
    //初始化数据 根据员工汇总
    @PreAuthorize("@ss.hasPermi('station:structure:selectPersonnelStructure')")
    @GetMapping("/selectPersonnelStructure")
    public TableDataInfo selectPersonnelStructure(StationClassStructure stationClassStructure)
    {
        //根据油站查询出上次班结时间，
        stationClassStructure.setStationId(Long.valueOf("5"));
        StationClassStructure  structure=  stationClassStructureService.selectStationClassStructureMax(stationClassStructure);
        List<StationClassStructure> list = new ArrayList<>();
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        if(structure!=null){
            PayOrder payOrder =new PayOrder();
            payOrder.setStationId(structure.getStationId());
            payOrder.setStatus("1");
            payOrder.setBeginTime(sdf.format(structure.getClassStructureDate()));
            List<PayOrder> payOrderList =  payOrderService.selectPersonnelStructure(payOrder);
            for(PayOrder order:payOrderList){
                StationClassStructure classStructure =new StationClassStructure();
                classStructure.setOilPersonnel(order.getOilPersonnel());
                classStructure.setOilGun(order.getOilGun());
                classStructure.setAmt(order.getAmt());
                classStructure.setOrderLiters(order.getOrderLiters());
                classStructure.setOrderNo(order.getOrderNo());
                list.add(classStructure);
            }
        }else{
           //根据上次班结时间，和油站去订单表中查询数据，并按照人员汇总数据
            PayOrder payOrder =new PayOrder();
            payOrder.setStatus("1");
            payOrder.setStationId(stationClassStructure.getStationId());
            List<PayOrder> payOrderList =  payOrderService.selectPersonnelStructure(payOrder);
            for(PayOrder order:payOrderList){
                StationClassStructure classStructure =new StationClassStructure();
                classStructure.setOilPersonnel(order.getOilPersonnel());
                classStructure.setOilGun(order.getOilGun());
                classStructure.setAmt(order.getAmt());
                classStructure.setOrderLiters(order.getOrderLiters());
                classStructure.setOrderNo(order.getOrderNo());
                list.add(classStructure);
            }
        }
        return getTable(list);
    }

    /**
     * 初始化数据班结数据，根据油品汇总
     * @param stationClassStructure
     * @return
     */
    @PreAuthorize("@ss.hasPermi('station:structure:selectOilStructure')")
    @GetMapping("/selectOilStructure")
    public TableDataInfo selectOilStructure(StationClassStructure stationClassStructure)
    {
        //根据油站查询出上次班结时间，
        stationClassStructure.setStationId(Long.valueOf("5"));
        StationClassStructure  structure=  stationClassStructureService.selectStationClassStructureMax(stationClassStructure);
        List<StationClassStructure> list = new ArrayList<>();
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        //根据上次班结时间，和油站去订单表中查询数据，并按照人员汇总数据
       if(structure!=null){
           PayOrder payOrder =new PayOrder();
           payOrder.setStatus("1");
           payOrder.setStationId(structure.getStationId());
           System.out.println("日期："+structure.getClassStructureDate());
           payOrder.setBeginTime(sdf.format(structure.getClassStructureDate()));
           List<PayOrder> payOrderList =  payOrderService.selectOilStructure(payOrder);
           for(PayOrder order:payOrderList){
               StationClassStructure classStructure =new StationClassStructure();
               classStructure.setOilName(order.getOilName());
               classStructure.setOilGun(order.getOilGun());
               classStructure.setAmt(order.getAmt());
               classStructure.setOrderLiters(order.getOrderLiters());
               classStructure.setOrderNo(order.getOrderNo());
               list.add(classStructure);
           }
       }else{
           PayOrder payOrder =new PayOrder();
           payOrder.setStatus("1");
           payOrder.setStationId(stationClassStructure.getStationId());
           List<PayOrder> payOrderList =  payOrderService.selectOilStructure(payOrder);
           for(PayOrder order:payOrderList){
               StationClassStructure classStructure =new StationClassStructure();
               classStructure.setOilName(order.getOilName());
               classStructure.setOilGun(order.getOilGun());
               classStructure.setAmt(order.getAmt());
               classStructure.setOrderLiters(order.getOrderLiters());
               classStructure.setOrderNo(order.getOrderNo());
               list.add(classStructure);
           }
       }

        return getTable(list);
    }
    /**
     * 初始化数据班结数据，根据员工/支付方式汇总
     * @param stationClassStructure
     * @return
     */
    @PreAuthorize("@ss.hasPermi('station:structure:selectPersonnelPayStructure')")
    @GetMapping("/selectPersonnelPayStructure")
    public TableDataInfo selectPersonnelPayStructure(StationClassStructure stationClassStructure)
    {
        //根据油站查询出上次班结时间，
        stationClassStructure.setStationId(Long.valueOf("5"));
        StationClassStructure  structure=  stationClassStructureService.selectStationClassStructureMax(stationClassStructure);
        List<StationClassStructure> list = new ArrayList<>();
        //根据上次班结时间，和油站去订单表中查询数据，并按照人员汇总数据
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        if(structure !=null){
            PayOrder payOrder =new PayOrder();
            payOrder.setStationId(structure.getStationId());
            payOrder.setStatus("1");
            System.out.println("日期："+structure.getClassStructureDate());
            payOrder.setBeginTime(sdf.format(structure.getClassStructureDate()));
            List<PayOrder> payOrderList =  payOrderService.selectPersonnelPayStructure(payOrder);
            for(PayOrder order:payOrderList){
                StationClassStructure classStructure =new StationClassStructure();
                classStructure.setOilPersonnel(order.getOilPersonnel());
                classStructure.setOilGun(order.getOilGun());
                classStructure.setWxNum(order.getWxNum());
                classStructure.setZfbNum(order.getZfbNum());
                classStructure.setXjNum(order.getXjNum());
                classStructure.setDiscountAmt(order.getDiscountAmt());
                classStructure.setDiscountCouponAmt(order.getDiscountCouponAmt());
                classStructure.setWxAmt(order.getWxAmt());
                classStructure.setZfbAmt(order.getZfbAmt());
                classStructure.setXjAmt(order.getXjAmt());
                classStructure.setMemberAmt(order.getMemberAmt());
                classStructure.setOrderLiters(order.getOrderLiters());
                classStructure.setOrderNo(order.getOrderNo());
                list.add(classStructure);
            }
        }else{
            PayOrder payOrder =new PayOrder();
            payOrder.setStatus("1");
            payOrder.setStationId(stationClassStructure.getStationId());
            List<PayOrder> payOrderList =  payOrderService.selectPersonnelPayStructure(payOrder);
            for(PayOrder order:payOrderList){
                StationClassStructure classStructure =new StationClassStructure();
                classStructure.setOilPersonnel(order.getOilPersonnel());
                classStructure.setOilGun(order.getOilGun());
                classStructure.setWxNum(order.getWxNum());
                classStructure.setZfbNum(order.getZfbNum());
                classStructure.setXjNum(order.getXjNum());
                classStructure.setDiscountAmt(order.getDiscountAmt());
                classStructure.setDiscountCouponAmt(order.getDiscountCouponAmt());
                classStructure.setWxAmt(order.getWxAmt());
                classStructure.setZfbAmt(order.getZfbAmt());
                classStructure.setXjAmt(order.getXjAmt());
                classStructure.setMemberAmt(order.getMemberAmt());
                classStructure.setOrderLiters(order.getOrderLiters());
                classStructure.setOrderNo(order.getOrderNo());
                list.add(classStructure);
            }
        }
        return getTable(list);
    }


}
